# Stubs for docutils.utils.smartquotes (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Dict, Generator, Iterable, Tuple

options: str
default_smartypants_attr: str

class smartchars:
    endash: str = ...
    emdash: str = ...
    ellipsis: str = ...
    apostrophe: str = ...
    quotes: Dict[str, Any] = ...
    language: str = ...
    def __init__(self, language: str = ...) -> None: ...

def smartyPants(text: str, attr: str = ..., language: str = ...) -> str: ...
def educate_tokens(text_tokens: Iterable[Tuple[str, str]], attr: str = ..., language: str = ...) -> Generator[str, None, None]: ...
def educateQuotes(text: str, language: str = ...) -> str: ...
def educateBackticks(text: str, language: str = ...) -> str: ...
def educateSingleBackticks(text: str, language: str = ...) -> str: ...
def educateDashes(text: str) -> str: ...
def educateDashesOldSchool(text: str) -> str: ...
def educateDashesOldSchoolInverted(text: str) -> str: ...
def educateEllipses(text: str) -> str: ...
def stupefyEntities(text: str, language: str = ...) -> str: ...
def processEscapes(text: str, restore: bool = ...) -> str: ...
def tokenize(text: str) -> Generator[Tuple[str, str], None, None]: ...
