# Stubs for docutils.utils.error_reporting (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import IO, Optional

locale_encoding: str

class SafeString:
    data: str = ...
    encoding: str = ...
    encoding_errors: str = ...
    decoding_errors: str = ...
    def __init__(self, data: str, encoding: Optional[str] = ..., encoding_errors: str = ..., decoding_errors: str = ...) -> None: ...
    def __unicode__(self) -> str: ...

class ErrorString(SafeString):
    def __unicode__(self) -> str: ...

class ErrorOutput:
    stream: IO = ...
    encoding: str = ...
    encoding_errors: str = ...
    decoding_errors: str = ...
    def __init__(self, stream: Optional[IO] = ..., encoding: Optional[str] = ..., encoding_errors: str = ..., decoding_errors: str = ...) -> None: ...
    def write(self, data: str) -> None: ...
    def close(self) -> None: ...
