# Stubs for docutils.writers.docutils_xml (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

import docutils
from docutils import nodes, writers
from docutils.writers import docutils_xml
from typing import Any, Dict, List, Sequence, Tuple
import xml.sax.saxutils
import xml.sax.xmlreader.XMLReader

__docformat__: str

class RawXmlError(docutils.ApplicationError): ...

class Writer(writers.Writer):
    supported: Tuple[str, ...] = ...
    settings_spec: Tuple[str, Any, Tuple[Tuple[str, List[str], Dict[str, Any]], ...]] = ...
    settings_defaults: Dict[str, str] = ...
    config_section: str = ...
    config_section_dependencies: Sequence[str] = ...
    output: Any = ...
    translator_class: Any = ...
    def __init__(self) -> None: ...
    visitor: Any = ...
    def translate(self) -> None: ...

class XMLTranslator(nodes.GenericNodeVisitor):
    xml_declaration: str = ...
    doctype: str = ...
    generator: str = ...
    xmlparser: xml.sax.xmlreader.XMLReader = ...
    warn: Any = ...
    error: Any = ...
    settings: Any = ...
    indent: str = ...
    newline: str = ...
    level: int = ...
    in_simple: int = ...
    fixed_text: int = ...
    output: List[Any] = ...
    the_handle: docutils_xml.TestXml = ...
    def __init__(self, document: nodes.document) -> None: ...
    simple_nodes: Tuple[nodes.Node, ...] = ...
    def default_visit(self, node: nodes.Node) -> None: ...
    def default_departure(self, node: nodes.Node) -> None: ...
    def visit_Text(self, node: nodes.Text) -> None: ...
    def depart_Text(self, node: nodes.Text) -> None: ...
    def visit_raw(self, node: nodes.raw) -> None: ...

class TestXml(xml.sax.ContentHandler):  # type: ignore
    locator: Any = ...
    def setDocumentLocator(self, locator: Any) -> None: ...
