# Stubs for docutils.writers.pseudoxml (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils import writers
from typing import Any, Sequence, Tuple

__docformat__: str

class Writer(writers.Writer):
    supported: Tuple[str, ...] = ...
    config_section: str = ...
    config_section_dependencies: Sequence[str] = ...
    output: str = ...
    def translate(self) -> None: ...
    def supports(self, format: Any) -> bool: ...
