# Stubs for docutils (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, List, Tuple, Type
from docutils.transforms import Transform

__docformat__: str
__version__: str
__version_info__: Tuple[int, int, int, str, int, bool]
__version_details__: str

class ApplicationError(Exception):
    def __unicode__(self) -> str: ...

class DataError(ApplicationError): ...

class SettingsSpec:
    settings_spec: Any = ...
    settings_defaults: Any = ...
    settings_default_overrides: Any = ...
    relative_path_settings: Any = ...
    config_section: str = ...
    config_section_dependencies: Any = ...

class TransformSpec:
    def get_transforms(self) -> List[Type[Transform]]: ...
    default_transforms: Tuple[Transform] = ...
    unknown_reference_resolvers: Any = ...

class Component(SettingsSpec, TransformSpec):
    component_type: str = ...
    supported: Tuple[str, ...] = ...
    def supports(self, format: str) -> bool: ...
