# Stubs for docutils.parsers (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils import Component
from docutils import nodes
from docutils.statemachine import StringList

__docformat__: str

class Parser(Component):
    component_type: str = ...
    config_section: str = ...
    def parse(self, inputstring: str, document: nodes.document) -> None: ...
    inputstring: str = ...
    document: nodes.document = ...
    def setup_parse(self, inputstring: StringList, document: nodes.document) -> None: ...
    def finish_parse(self) -> None: ...

def get_parser_class(parser_name: str) -> Parser: ...
