# Stubs for docutils.utils.roman (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Pattern, Tuple

__date__: str
__copyright__: str

class RomanError(Exception): ...
class OutOfRangeError(RomanError): ...
class NotIntegerError(RomanError): ...
class InvalidRomanNumeralError(RomanError): ...

romanNumeralMap: Tuple[Tuple[str, int], ...]

def toRoman(n: int) -> str: ...

romanNumeralPattern: Pattern

def fromRoman(s: str) -> int: ...
