# Stubs for docutils.utils.math.tex2unichar (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Dict

mathaccent: Dict[str, str]
mathalpha: Dict[str, str]
mathbin: Dict[str, str]
mathclose: Dict[str, str]
mathfence: Dict[str, str]
mathop: Dict[str, str]
mathopen: Dict[str, str]
mathord: Dict[str, str]
mathover: Dict[str, str]
mathradical: Dict[str, str]
mathrel: Dict[str, str]
mathunder: Dict[str, str]
space: Dict[str, str]
