# Stubs for docutils.parsers.rst.languages.en (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Dict

__docformat__: str
directives: Dict[str, str]
roles: Dict[str, str]
