# Stubs for docutils.writers.pep_html (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils import nodes
from docutils.writers import html4css1, pep_html
from typing import Dict, List, Sequence, Tuple, Type

__docformat__: str

class Writer(html4css1.Writer):
    default_stylesheet: str = ...
    default_stylesheet_path: str = ...
    default_template: str = ...
    default_template_path: str = ...
    settings_spec: Tuple[str, str, Tuple[Tuple[str, List[str], Dict[str, str]], ...]] = ...
    settings_default_overrides: Dict[str, str] = ...
    relative_path_settings: Tuple[str, ...] = ...
    config_section: str = ...
    config_section_dependencies: Sequence[str] = ...
    translator_class: Type[pep_html.HTMLTranslator] = ...
    def __init__(self) -> None: ...
    pepnum: str = ...
    title: str = ...
    def interpolation_dict(self) -> Dict[str, str]: ...
    def assemble_parts(self) -> None: ...

class HTMLTranslator(html4css1.HTMLTranslator):
    def depart_field_list(self, node: nodes.field_list) -> None: ...
