# Stubs for docutils.transforms.components (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils.transforms import Transform

__docformat__: str

class Filter(Transform):
    default_priority: int = ...
    def apply(self) -> None: ...  # type: ignore
