# Stubs for docutils.examples (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils.core import Publisher
from typing import Any, Dict, Optional, Tuple

def html_parts(input_string, source_path: Optional[Any] = ..., destination_path: Optional[Any] = ..., input_encoding: str = ..., doctitle: bool = ..., initial_header_level: int = ...) -> Dict[str, Any]: ...
def html_body(input_string, source_path: Optional[Any] = ..., destination_path: Optional[Any] = ..., input_encoding: str = ..., output_encoding: str = ..., doctitle: bool = ..., initial_header_level: int = ...) -> Any: ...
def internals(input_string, source_path: Optional[Any] = ..., destination_path: Optional[Any] = ..., input_encoding: str = ..., settings_overrides: Optional[Any] = ...) -> Tuple[Any, Publisher]: ...
