# Stubs for docutils.languages.it (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Dict, List

__docformat__: str
labels: Dict[str, str]
bibliographic_fields: Dict[str, str]
author_separators: List[str]
