# Stubs for docutils.readers.standalone (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils import nodes
from docutils import readers
from docutils.transforms import Transform
from typing import Any, Dict, List, Sequence, Tuple, Type

__docformat__: str

class Reader(readers.Reader):
    supported: Tuple[str, ...] = ...
    document: nodes.document = ...
    settings_spec: Tuple[str, str, Tuple[str, List[str], Dict[str, Any]]] = ...
    config_section: str = ...
    config_section_dependencies: Sequence[str] = ...
    def get_transforms(self) -> List[Type[Transform]]: ...
