# Stubs for docutils.utils.punctuation_chars (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Dict

openers: str
closers: str
delimiters: str
closing_delimiters: str
quote_pairs: Dict[str, str]

def match_chars(c1: str, c2: str) -> bool: ...
