# Stubs for docutils.readers.doctree (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils import nodes
from docutils import readers
from typing import Sequence, Tuple

class Reader(readers.ReReader):
    supported: Tuple[str, ...] = ...
    config_section: str = ...
    config_section_dependencies: Sequence[str] = ...
    document: nodes.document = ...
    def parse(self) -> None: ...
