# Stubs for docutils._compat (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, List, Mapping

b = str
bytes = str
u_prefix: str

def __import__(name, globals: Mapping[Any, Any] = ..., locals: Mapping[Any, Any] = ..., fromlist: List[Any] = ..., level: int = ...): ...
