# Stubs for docutils.parsers.rst.languages (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from types import ModuleType

__docformat__: str

def get_language(language_code: str) -> ModuleType: ...
