# Stubs for docutils.writers.s5_html (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils import nodes
from docutils.writers import html4css1, s5_html
from typing import Any, Dict, List, Optional, Pattern, Tuple, Type

__docformat__: str
themes_dir_path: str

def find_theme(name: str): ...

class Writer(html4css1.Writer):
    settings_spec: Tuple[str, Any, Tuple[Tuple[str, List[str], Dict[str, Any]], ...], str, Any, Tuple[Tuple[str, List[str], Dict[str, Any]], ...]] = ...  # type: ignore
    settings_default_overrides: Dict[str, int] = ...
    config_section: str = ...
    config_section_dependencies: Tuple[str, ...] = ...
    translator_class: Type[s5_html.S5HTMLTranslator] = ...
    def __init__(self) -> None: ...

class S5HTMLTranslator(html4css1.HTMLTranslator):
    s5_stylesheet_template: str = ...
    disable_current_slide: str = ...
    layout_template: str = ...
    default_theme: str = ...
    base_theme_file: str = ...
    direct_theme_files: Tuple[str] = ...
    indirect_theme_files: Tuple[str] = ...
    required_theme_files: Tuple[str] = ...
    theme_file_path: str = ...
    s5_footer: List[str] = ...
    s5_header: List[str] = ...
    section_count: int = ...
    theme_files_copied: Optional[Dict[str, int]] = ...
    def __init__(self, *args) -> None: ...
    def setup_theme(self) -> None: ...
    def copy_theme(self) -> None: ...
    files_to_skip_pattern: Pattern[str] = ...
    def copy_file(self, name: str, source_dir: str, dest_dir: str) -> Optional[int]: ...
    def depart_document(self, node: nodes.document) -> None: ...
    def depart_footer(self, node: nodes.footer) -> None: ...
    def depart_header(self, node: nodes.header) -> None: ...
    def visit_section(self, node: nodes.section) -> None: ...
    def visit_subtitle(self, node: nodes.subtitle) -> None: ...
    def visit_title(self, node: nodes.title) -> None: ...
