# Stubs for docutils.utils.code_analyzer (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils import ApplicationError
from typing import Any, Generator, List, Tuple

with_pygments: bool
unstyled_tokens: List[str]

class LexerError(ApplicationError): ...

class Lexer:
    code: str = ...
    language: str = ...
    tokennames: str = ...
    lexer: Any = ...
    def __init__(self, code: str, language: str, tokennames: str = ...) -> None: ...
    def merge(self, tokens: List[Tuple[str, str]]) -> Generator[Tuple[str, str], None, None]: ...
    def __iter__(self) -> Generator[Tuple[List[str], str], None, None]: ...

class NumberLines:
    tokens: Tuple[List[str], str] = ...
    startline: int = ...
    fmt_str: int = ...
    def __init__(self, tokens: Tuple[List[str], str], startline: int, endline: int) -> None: ...
    def __iter__(self) -> Generator[Tuple[str, str], None, None]: ...
