# Stubs for docutils.parsers.rst.directives.parts (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils.nodes import Node
from docutils.parsers.rst import Directive
from typing import Any, Callable, Dict, List, Tuple, TypeVar

N_co = TypeVar('N_co', bound=Node, covariant=True)

__docformat__: str

class Contents(Directive):
    backlinks_values: Tuple[str, ...] = ...
    def backlinks(arg): ...
    optional_arguments: int = ...
    final_argument_whitespace: bool = ...
    option_spec: Dict[str, Callable[[str], Any]] = ...
    def run(self) -> List[N_co]: ...

class Sectnum(Directive):
    option_spec: Dict[str, Callable[[str], Any]] = ...
    def run(self) -> List[N_co]: ...

class Header(Directive):
    has_content: bool = ...
    def run(self) -> List[N_co]: ...

class Footer(Directive):
    has_content: bool = ...
    def run(self) -> List[N_co]: ...
