# Stubs for docutils.parsers.rst.directives.admonitions (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils import nodes
from docutils.nodes import Node, admonition, attention, caution, danger, error, hint, important, note, tip, warning
from docutils.parsers.rst import Directive
from typing import Any, Callable, Dict, List, Type, TypeVar

N_co = TypeVar('N_co', bound=Node, covariant=True)

__docformat__: str

class BaseAdmonition(Directive):
    final_argument_whitespace: bool = ...
    option_spec: Dict[str, Callable[[str], Any]] = ...
    has_content: bool = ...
    node_class: Type[nodes.Admonition] = ...
    def run(self) -> List[N_co]: ...

class Admonition(BaseAdmonition):
    required_arguments: int = ...
    node_class: Type[admonition] = ...

class Attention(BaseAdmonition):
    node_class: Type[attention] = ...

class Caution(BaseAdmonition):
    node_class: Type[caution] = ...

class Danger(BaseAdmonition):
    node_class: Type[danger] = ...

class Error(BaseAdmonition):
    node_class: Type[error] = ...

class Hint(BaseAdmonition):
    node_class: Type[hint] = ...

class Important(BaseAdmonition):
    node_class: Type[important] = ...

class Note(BaseAdmonition):
    node_class: Type[note] = ...

class Tip(BaseAdmonition):
    node_class: Type[tip] = ...

class Warning(BaseAdmonition):
    node_class: Type[warning] = ...
