# Stubs for docutils.readers (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils import Component
from docutils import nodes
from docutils.frontend import Values
from docutils.io import Input
from docutils.parsers import Parser
from docutils.transforms import Transform
from typing import Any, List, Optional, Type

__docformat__: str

class Reader(Component):
    component_type: str = ...
    config_section: str = ...
    def get_transforms(self) -> List[Type[Transform]]: ...
    parser: Parser = ...
    source: Input = ...
    input: Any = ...
    def __init__(self, parser: Optional[Parser] = ..., parser_name: Optional[str] = ...) -> None: ...
    def set_parser(self, parser_name: str) -> None: ...
    settings: Values = ...
    def read(self, source: Input, parser: Parser, settings: Values) -> nodes.document: ...
    document: nodes.document = ...
    def parse(self) -> None: ...
    def new_document(self) -> nodes.document: ...

class ReReader(Reader):
    def get_transforms(self) -> List[Type[Transform]]: ...

def get_reader_class(reader_name: str) -> Reader: ...
