# Stubs for docutils.utils.math.tex2mathml_extern (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils.utils import Reporter
from typing import Optional

document_template: str

def latexml(math_code: str, reporter: Optional[Reporter] = ...): ...
def ttm(math_code: str, reporter: Optional[Reporter] = ...): ...
def blahtexml(math_code: str, inline: bool = ..., reporter: Optional[Reporter] = ...): ...
