# Stubs for docutils.writers.null (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils import writers
from typing import Sequence, Tuple

class Writer(writers.UnfilteredWriter):
    supported: Tuple[str, ...] = ...
    config_section: str = ...
    config_section_dependencies: Sequence[str] = ...
    def translate(self) -> None: ...
