# Stubs for docutils.transforms.peps (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils import nodes
from docutils.transforms import Transform
from typing import Optional, Pattern, Sequence, Tuple

__docformat__: str

class Headers(Transform):
    default_priority: int = ...
    pep_url: str = ...
    pep_cvs_url: str = ...
    rcs_keyword_substitutions: Sequence[Tuple[Pattern, str]] = ...
    def apply(self) -> None: ...  # type: ignore

class Contents(Transform):
    default_priority: int = ...
    def apply(self) -> None: ...  # type: ignore

class TargetNotes(Transform):
    default_priority: int = ...
    def apply(self) -> None: ...  # type: ignore
    def cleanup_callback(self, pending: nodes.pending) -> None: ...

class PEPZero(Transform):
    default_priority: int = ...
    def apply(self) -> None: ...  # type: ignore

class PEPZeroSpecial(nodes.SparseNodeVisitor):
    pep_url: str = ...
    def unknown_visit(self, node: nodes.Node) -> None: ...
    def visit_reference(self, node: nodes.Node) -> None: ...
    def visit_field_list(self, node: nodes.Node) -> None: ...
    pep_table: bool = ...
    entry: int = ...
    def visit_tgroup(self, node: nodes.Node) -> None: ...
    def visit_colspec(self, node: nodes.Node) -> None: ...
    def visit_row(self, node: nodes.Node) -> None: ...
    def visit_entry(self, node: nodes.Node) -> None: ...

non_masked_addresses: Sequence[str]

def mask_email(ref: nodes.Node, pepno: Optional[int] = ...) -> nodes.Node: ...
