# Stubs for docutils.parsers.rst.directives.images (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils.nodes import Node
from docutils.parsers.rst import Directive
from typing import Any, Callable, Dict, List, Tuple, TypeVar

N_co = TypeVar('N_co', bound=Node, covariant=True)

__docformat__: str

class PIL: ...

class Image(Directive):
    align_h_values: Tuple[str, ...] = ...
    align_v_values: Tuple[str, ...] = ...
    align_values: Tuple[str, ...] = ...
    required_arguments: int = ...
    optional_arguments: int = ...
    final_argument_whitespace: bool = ...
    option_spec: Dict[str, Callable[[str], Any]] = ...
    def run(self) -> List[N_co]: ...

class Figure(Image):
    def align(argument): ...
    def figwidth_value(argument): ...
    option_spec: Dict[str, Callable[[str], Any]] = ...
    has_content: bool = ...
    def run(self) -> List[N_co]: ...
