# Stubs for docutils.readers.pep (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils.parsers import Parser
from docutils.parsers.rst.states import Inliner
from docutils.readers import standalone
from docutils.transforms import Transform
from typing import Any, Dict, List, Optional, Sequence, Tuple, Type

__docformat__: str

class Reader(standalone.Reader):
    supported: Tuple[str, ...] = ...
    settings_spec: Tuple[str, str, Tuple[str, List[str], Dict[str, Any]]] = ...
    config_section: str = ...
    config_section_dependencies: Sequence[str] = ...
    def get_transforms(self) -> List[Type[Transform]]: ...
    settings_default_overrides: Dict[str, Any] = ...
    inliner_class: Type[Inliner] = ...
    def __init__(self, parser: Optional[Parser] = ..., parser_name: Optional[str] = ...) -> None: ...
