# Stubs for docutils.languages (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from types import ModuleType
from typing import Optional
from docutils.utils import Reporter

__docformat__: str

def get_language(language_code: str, reporter: Optional[Reporter] = ...) -> ModuleType: ...
